%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                               %
%  PoKeys56U MATLAB example                                                     %
%  Tested in MATLAB7 (R14)                                                      %
%                                                                               %
%  This example contains:                                                       %
%   - number of devices,                                                        %
%   - connect to device,                                                        %
%   - if the 2nd pin on device is connected with GND,                           %
%     start menu will open/close (simulation Ctrl + Esc)                        %
%   - the 3rd pin is declared as output pin                                     %
%     and is turned on true                                                     %
%   - disconnect                                                                %
%                                                                               %
%  For more information about PoKeys55 and for description of functions,        %
%  please read user's manual, protocol specification and DLL help:              %
%  - http://www.poscope.com/uploads/files/PoKeys.pdf                            %
%  - http://www.poscope.com/uploads/files/PoKeys%20protocol%20specification.pdf % 
%  - http://www.poscope.com/uploads/files/PoKeysDLL_help.zip                    %
%                                                                               %
%  support: www.poscope.com                                                     %
%                                                                               %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Create ActiveX server and save handle
PoKeys = actxserver('PoKeysDevice_DLL.PoKeysDevice');

%Number of devices
NumberOfDevices = get(PoKeys, 'EnumerateDevices')

if NumberOfDevices < 1
    disp('There are no devices');
    break;
end

%Connect to device
if get(PoKeys, 'ConnectToDevice', 0)
    disp('Connected');
else
    disp('Connection failed');
    break;
end

%Set pin data
%1 - zero-based pin index on the device (2nd pin - pin No.1)
%130 - inverted
get(PoKeys, 'SetPinData_2', 1, 130);
%Set pin key mapping
%1 - 2nd pin
%41 - Esc
%1 - Ctrl
get(PoKeys, 'SetPinKeyMapping', 1, 41, 1);

%Set pin data
%2 - 3rd pin
%4 - output
get(PoKeys, 'SetPinData_2', 2, 4);
%Set output
%2 - 3rd pin
%true - output state
get(PoKeys, 'SetOutput', 2, true);

%Save configuration
get(PoKeys, 'SaveConfiguration');

%Disconnect device
get(PoKeys, 'DisconnectDevice');
disp('Disconnected');

%Delete handle
delete(PoKeys);

